==> haskell-hasql-implicits-0.1.0.5-249-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-implicits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-implicits
version:              0.1.0.5
visibility:           public
id:                   hasql-implicits-0.1.0.5-K3fJD2XWiXB6IWsPlbUyde
key:                  hasql-implicits-0.1.0.5-K3fJD2XWiXB6IWsPlbUyde
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-implicits
synopsis:
    Implicit definitions for Hasql, such as default codecs for standard types

abi:                  7e9db75b5e68309a334b0ee7d2925769
exposed:              True
exposed-modules:      Hasql.Implicits.Encoders
hidden-modules:       Hasql.Implicits.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-implicits
hs-libraries:         HShasql-implicits-0.1.0.5-K3fJD2XWiXB6IWsPlbUyde
depends:
    aeson-2.1.2.1-HUj8Ou2Jrr19darX8iyQt4 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    hasql-1.5.0.5-7WOUcIdLsg28Ynmg26doSq
    network-ip-0.3.0.3-LQyiPjacF7fAxkPn3vDjSN
    scientific-0.3.8.0-3JrZTDh3ZlGFN4TNaQrQZi text-2.0.2 time-1.12.2
    uuid-1.3.16-DPBdxgPSdwL3Pxt9uhiBrd
    vector-0.13.2.0-GDtmlcfK9QZ7E5AlTQVnIi

haddock-interfaces:
    /usr/share/doc/haskell-hasql-implicits/html/hasql-implicits.haddock

haddock-html:         /usr/share/doc/haskell-hasql-implicits/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-implicits-0.1.0.5-250-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-implicits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-implicits
version:              0.1.0.5
visibility:           public
id:                   hasql-implicits-0.1.0.5-D4bD7ZStGkUKPfmPphoRls
key:                  hasql-implicits-0.1.0.5-D4bD7ZStGkUKPfmPphoRls
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-implicits
synopsis:
    Implicit definitions for Hasql, such as default codecs for standard types

abi:                  3bafe26ed4619381fce322abef301aed
exposed:              True
exposed-modules:      Hasql.Implicits.Encoders
hidden-modules:       Hasql.Implicits.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-implicits
hs-libraries:         HShasql-implicits-0.1.0.5-D4bD7ZStGkUKPfmPphoRls
depends:
    aeson-2.1.2.1-7goQjQKasWuq7oOasot83 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    hasql-1.5.0.5-I3LpRXfzXVTC67F3ohwQHt
    network-ip-0.3.0.3-9clVHTC5n7w5cFPYYphWn1
    scientific-0.3.8.0-HfCn6ildxXk6zQelWj77aL text-2.0.2 time-1.12.2
    uuid-1.3.16-3mmlRuZQrBG6AoM06zopKx
    vector-0.13.2.0-GjxrA8HCtQq4MGRlxeWifh

haddock-interfaces:
    /usr/share/doc/haskell-hasql-implicits/html/hasql-implicits.haddock

haddock-html:         /usr/share/doc/haskell-hasql-implicits/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
